Documentation
¶
Index ¶
Constants ¶
const (
LoadBalancerFinalizer = "loadbalancer.cloudscale.appuio.io/finalizer"
)
const MetricsNamespace = "cloudscale_loadbalancer_controller"
Variables ¶
This section is empty.
Functions ¶
func IsCloudscaleNotFoundErr ¶
IsCloudscaleNotFoundErr checks if the error is a Cloudscale not found error.
Types ¶
type LoadBalancerReconciler ¶
type LoadBalancerReconciler struct {
client.Client
Scheme *runtime.Scheme
Recorder record.EventRecorder
// MaxReconcileInterval is the maximum interval between two reconciles of a LoadBalancer object.
// Can be lowered to speed up reconciliation of external state changes.
// Defaults to 5 minutes.
MaxReconcileInterval time.Duration
ServerClient cloudscale.ServerService
FloatingIPsClient cloudscale.FloatingIPsService
LoadbalancerClient cloudscale.LoadBalancerService
LoadbalancerHealthMonitorClient cloudscale.LoadBalancerHealthMonitorService
LoadbalancerListenerClient cloudscale.LoadBalancerListenerService
LoadbalancerPoolClient cloudscale.LoadBalancerPoolService
LoadbalancerPoolMemberClient cloudscale.LoadBalancerPoolMemberService
}
LoadBalancerReconciler reconciles a LoadBalancer object
func (*LoadBalancerReconciler) Reconcile ¶
func (r *LoadBalancerReconciler) Reconcile(ctx context.Context, req ctrl.Request) (res ctrl.Result, err error)
Reconcile compares the LoadBalancer object with the upstream LoadBalancer object and updates the upstream LoadBalancer object if necessary.
func (*LoadBalancerReconciler) SetupWithManager ¶
func (r *LoadBalancerReconciler) SetupWithManager(name string, mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type LoadBalancerStatusCollector ¶
LoadBalancerStatusCollector is a Prometheus collector that exposes various metrics about the upgrade process.
func (*LoadBalancerStatusCollector) Collect ¶
func (m *LoadBalancerStatusCollector) Collect(ch chan<- prometheus.Metric)
Collect implements prometheus.Collector. Sends a metric if the cluster is currently upgrading and an upgrading metric for each machine config pool. It also collects job states and whether they have matching disruptive hooks.
func (*LoadBalancerStatusCollector) Describe ¶
func (*LoadBalancerStatusCollector) Describe(ch chan<- *prometheus.Desc)
Describe implements prometheus.Collector. Sends the static description of the metrics to the provided channel.